@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 8; tab-width: 8 -*- */
 
 /* nautilus-ui-utilities.h - helper functions for GtkUIManager stuff
 
@@ -47,4 +47,9 @@ char * nautilus_escape_action_name                 (const char        *action_na
 void   nautilus_ui_frame_image                     (GdkPixbuf        **pixbuf);
 void   nautilus_ui_frame_video                     (GdkPixbuf        **pixbuf);
 
+gboolean   nautilus_file_date_in_between           (guint64           file_unix_time,
+                                                    GDateTime         *initial_date,
+                                                    GDateTime         *end_date);
+gchar*     get_text_for_date_range                 (GPtrArray         *date_range);
+
 #endif /* NAUTILUS_UI_UTILITIES_H */
