@@ -480,7 +480,7 @@ nautilus_drag_slot_proxy_init (GtkWidget *widget,
   drag_info->is_notebook = (g_object_get_data (G_OBJECT (widget), "nautilus-notebook-tab") != NULL);
 
   if (target_file != NULL)
-    drag_info->target_file = g_object_ref (target_file);
+    drag_info->target_file = nautilus_file_ref (target_file);
 
   if (target_slot != NULL)
     drag_info->target_slot = g_object_ref (target_slot);
